/* utf16.h
 *  Copyright (C) 2004-2007, The Perl Foundation.
 *  SVN Info
 *     $Id: utf16.h 19796 2007-07-11 22:09:12Z petdance $
 *  Overview:
 *     This is the header for the utf16 variable-width encoding.
 *  Data Structure and Algorithms:
 *  History:
 *  Notes:
 *  References:
 */

#ifndef PARROT_ENCODING_UTF16_H_GUARD
#define PARROT_ENCODING_UTF16_H_GUARD

/* HEADERIZER BEGIN: src/encodings/utf16.c */

ENCODING * Parrot_encoding_utf16_init( PARROT_INTERP )
        __attribute__nonnull__(1);

/* HEADERIZER END: src/encodings/utf16.c */

#endif /* PARROT_ENCODING_UTF16_H_GUARD */

/*
 * Local variables:
 *   c-file-style: "parrot"
 * End:
 * vim: expandtab shiftwidth=4:
 */
